--
-- BR6090
--
BR6090 = {};

function BR6090.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Fillable, specializations);
end;

function BR6090:load(xmlFile)
	self.getIsAreaActive = Utils.overwrittenFunction(self.getIsAreaActive, BR6090.getIsAreaActive);	
	self.setTransport= SpecializationUtil.callSpecializationsFunction("setTransport");	
	self.setPickup= SpecializationUtil.callSpecializationsFunction("setPickup");	
	-- Animations --
	self.PickupAnimation = getXMLString(xmlFile, "vehicle.Pickup#animationName");
	self.Pickup = false;
	-- Animated objects --
	self.numRotParts = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.RotParts#count"), 0);	
    self.RotParts = {};
    for i=1, self.numRotParts do
        local RotPartsnamei = string.format("vehicle.RotParts.RotPart" .. "%d", i);
        self.RotParts[i] = Utils.indexToObject(self.components, getXMLString(xmlFile, RotPartsnamei .. "#index"));
    end;
	self.PickupWheels = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.PickupWheels#index"));
	-- Particles --
	self.PickUpParticleSystems = {};
    local i = 0;
    while true do
        local namei = string.format("vehicle.PickUpParticleSystems.PickUpParticleSystems(%d)", i);
		local nodei = Utils.indexToObject(self.components, getXMLString(xmlFile, namei .. "#index"));
		if nodei == nil then
			break;
		end; 
        Utils.loadParticleSystem(xmlFile, self.PickUpParticleSystems, namei, nodei, false, nil, self.baseDirectory)		
		i = i +1;		
    end;

	
end;

function BR6090:delete()
	Utils.deleteParticleSystem(self.PickUpParticleSystems);
end;

function BR6090:readStream(streamId, connection)
    self:setPickup(streamReadBool(streamId), true);
    self:setTransport(streamReadBool(streamId), true);
end;

function BR6090:writeStream(streamId, connection)
    streamWriteBool(streamId, self.Pickup);
    streamWriteBool(streamId, self.Transport);
end;

function BR6090:readUpdateStream(streamId, timestamp, connection)
end;

function BR6090:writeUpdateStream(streamId, connection, dirtyMask)
end;

function BR6090:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BR6090:keyEvent(unicode, sym, modifier, isDown)
end;

function BR6090:update(dt)	
 	
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.LOWER_IMPLEMENT) then
			self:setPickup(not self.Pickup);
		end;
    end;
end;

function BR6090:updateTick(dt)	
	if self:getIsActive() then	
		-- Animating the pickup elements --
		if self.isTurnedOn and not self.Transport then
			for i=1, 2 do
				rotate(self.RotParts[i], 0.01 * dt, 0, 0);
			end;
			rotate(self.PickupWheels, 2.5 * self.lastSpeedReal * self.movingDirection * dt ,0,0);
		end;			
		-- Activate particles --
		if self.isTurnedOn and not self.Transport and self.movingDirection ~= 0 and self.PickupDown then
			Utils.setEmittingState(self.PickUpParticleSystems, true);
		else
			Utils.setEmittingState(self.PickUpParticleSystems, false);
		end;
	end;	
end;

function BR6090:draw()
		if self.PickupDown then
			g_currentMission:addHelpButtonText(string.format(g_i18n:getText("PICKUP_LIFTBR"), self.typeDesc), InputBinding.LOWER_IMPLEMENT);
		else
			g_currentMission:addHelpButtonText(string.format(g_i18n:getText("PICKUP_LOWERBR"), self.typeDesc), InputBinding.LOWER_IMPLEMENT);
		end;
    end;	

function BR6090:setPickup(isPickupState,noEventSend)
	SetPickupEvent.sendEvent(self, isPickupState, noEventSend);
	-- Play pickup animation --
	self.PickupDown = isPickupState;
	if self.PickupDown then
		if self.PickupAnimation ~= nil and self.playAnimation ~= nil then
			self:playAnimation(self.PickupAnimation, -1, nil, true);
			self.Pickup = true;
		end;
	else
		if self.PickupAnimation ~= nil and self.playAnimation ~= nil then
			self:playAnimation(self.PickupAnimation, 1, nil, true);
			self.Pickup = false;
		end;
	end;	
end;

function BR6090:onDetach()
	if self.PickUpParticleSystems ~= nil then
		Utils.setEmittingState(self.PickUpParticleSystems, false);
	end;
end;

function BR6090:getIsAreaActive(superFunc, area)
    if superFunc ~= nil then
			return superFunc(self, area) and self.PickupDown;
    end;
	return self.PickupDown;	
end;